﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace GasolineTanker
{
    internal class DrawingGasolineTanker
    {
        public EnityGasolineTanker GasolineTanker { get; private set; }
        private float _startPosX;
        private float _startPosY;
        private int? _pictureWidth = null;
        private int? _pictureHeight = null;
        private readonly int _gasolineTankerWidth = 160;
        private readonly int _gasolineTankerHeight = 55;

        public void Init(int speed, float weight, Color bodyColor)
        {
            GasolineTanker = new EnityGasolineTanker();
            GasolineTanker.Init(speed, weight, bodyColor);
        }

        public void SetPosition(int x, int y, int width, int height)
        {
            if (x >= 0 && x + _gasolineTankerWidth <= width && y >= 0 && y + _gasolineTankerHeight <= height)
            {
                _startPosX = x;
                _startPosY = y;
                _pictureWidth = width;
                _pictureHeight = height;
            }
        }

        public void MoveTransport(Direction direction)
        {
            if (!_pictureWidth.HasValue || !_pictureHeight.HasValue)
            {
                return;
            }
            switch (direction)
            {
                // вправо
                case Direction.Right:
                    if (_startPosX + _gasolineTankerWidth + GasolineTanker.Step < _pictureWidth)
                    {
                        _startPosX += GasolineTanker.Step;
                    }
                    break;
                //влево
                case Direction.Left:
                    if (_startPosX - GasolineTanker.Step > 0)
                    {
                        _startPosX -= GasolineTanker.Step;
                    }
                    break;
                //вверх
                case Direction.Up:
                    if (_startPosY - GasolineTanker.Step > 0)
                    {
                        _startPosY -= GasolineTanker.Step;
                    }
                    break;
                //вниз
                case Direction.Down:
                    if (_startPosY + _gasolineTankerHeight + GasolineTanker.Step < _pictureHeight)
                    {
                        _startPosY += GasolineTanker.Step;
                    }
                    break;
            }
        }
        public void DrawTransport(Graphics g)
        {
            if (_startPosX < 0 || _startPosY < 0
                || !_pictureHeight.HasValue || !_pictureWidth.HasValue)
            {
                return;
            }
            Pen pen = new(Color.Black);

            Brush brBlack = new SolidBrush(Color.Black);
            g.FillEllipse(brBlack, _startPosX + 130, _startPosY + 35, 20, 20);
            g.FillEllipse(brBlack, _startPosX + 10, _startPosY + 35, 20, 20);
            g.FillEllipse(brBlack, _startPosX + 30, _startPosY + 35, 20, 20);

            Brush brRed = new SolidBrush(Color.Red);
            g.FillEllipse(brRed, _startPosX+5, _startPosY + 35, 10, 10);

            Brush brYellow = new SolidBrush(Color.Yellow);
            g.FillEllipse(brYellow, _startPosX + 140, _startPosY + 30, 10, 10);

            Brush br = new SolidBrush(GasolineTanker?.BodyColor ?? Color.Black);
            g.FillRectangle(br, _startPosX + 115, _startPosY+5, 40, 40);
            g.FillRectangle(br, _startPosX + 10, _startPosY + 35, 140, 10);

            Brush brBlue = new SolidBrush(Color.LightBlue);
            g.FillRectangle(brBlue, _startPosX + 120, _startPosY + 10, 25, 25);

            g.DrawRectangle(pen, _startPosX + 120, _startPosY + 10, 25, 25);
            g.DrawRectangle(pen, _startPosX + 115, _startPosY + 5, 40, 40);
            g.DrawRectangle(pen, _startPosX + 10, _startPosY + 35, 105, 10);
        }
         public void ChangeBorders(int width, int height)
        {
            _pictureWidth = width;
            _pictureHeight = height;
            if (_pictureWidth <= _gasolineTankerWidth || _pictureHeight <= _gasolineTankerHeight)
            {
                _pictureWidth = null;
                _pictureHeight = null;
                return;
            }
            if (_startPosX + _gasolineTankerWidth > _pictureWidth)
            {
                _startPosX = _pictureWidth.Value - _gasolineTankerWidth;
            }
            if (_startPosY + _gasolineTankerHeight > _pictureHeight)
            {
                _startPosY = _pictureHeight.Value - _gasolineTankerHeight;
            }
        }
    }
}
